@@ -21,12 +21,12 @@ import (
 	"net/http"
 	"testing"
 
-	triggersv1 "github.com/tektoncd/triggers/pkg/apis/triggers/v1alpha1"
+	triggersv1 "github.com/tektoncd/triggers/pkg/apis/triggers/v1beta1"
 	"github.com/tektoncd/triggers/test"
 	"go.uber.org/zap/zaptest"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	fakekubeclient "knative.dev/pkg/client/injection/kube/client/fake"
+	fakeSecretInformer "knative.dev/pkg/client/injection/kube/informers/core/v1/secret/fake"
 	rtesting "knative.dev/pkg/reconciler/testing"
 )
 
@@ -108,7 +108,7 @@ func TestInterceptor_ExecuteTrigger_Signature(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			ctx, _ := rtesting.SetupFakeContext(t)
 			logger := zaptest.NewLogger(t)
-			kubeClient := fakekubeclient.Get(ctx)
+			secretInformer := fakeSecretInformer.Get(ctx)
 
 			req := &triggersv1.InterceptorRequest{
 				Body: string(tt.payload),
@@ -132,13 +132,15 @@ func TestInterceptor_ExecuteTrigger_Signature(t *testing.T) {
 				req.Header["X-Hub-Signature"] = []string{tt.signature}
 			}
 			if tt.secret != nil {
-				if _, err := kubeClient.CoreV1().Secrets(metav1.NamespaceDefault).Create(ctx, tt.secret, metav1.CreateOptions{}); err != nil {
-					t.Error(err)
+				tt.secret.Namespace = metav1.NamespaceDefault
+				if err := secretInformer.Informer().GetIndexer().Add(tt.secret); err != nil {
+					t.Fatal(err)
 				}
 			}
+
 			w := &Interceptor{
-				KubeClientSet: kubeClient,
-				Logger:        logger.Sugar(),
+				SecretLister: secretInformer.Lister(),
+				Logger:       logger.Sugar(),
 			}
 			res := w.Process(ctx, req)
 
@@ -268,7 +270,7 @@ func TestInterceptor_ExecuteTrigger_ShouldNotContinue(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			ctx, _ := rtesting.SetupFakeContext(t)
 			logger := zaptest.NewLogger(t)
-			kubeClient := fakekubeclient.Get(ctx)
+			secretInformer := fakeSecretInformer.Get(ctx)
 
 			req := &triggersv1.InterceptorRequest{
 				Body: string(tt.payload),
@@ -292,13 +294,14 @@ func TestInterceptor_ExecuteTrigger_ShouldNotContinue(t *testing.T) {
 				req.Header["X-Hub-Signature"] = []string{tt.signature}
 			}
 			if tt.secret != nil {
-				if _, err := kubeClient.CoreV1().Secrets(metav1.NamespaceDefault).Create(ctx, tt.secret, metav1.CreateOptions{}); err != nil {
-					t.Error(err)
+				tt.secret.Namespace = metav1.NamespaceDefault
+				if err := secretInformer.Informer().GetIndexer().Add(tt.secret); err != nil {
+					t.Fatal(err)
 				}
 			}
 			w := &Interceptor{
-				KubeClientSet: kubeClient,
-				Logger:        logger.Sugar(),
+				SecretLister: secretInformer.Lister(),
+				Logger:       logger.Sugar(),
 			}
 			res := w.Process(ctx, req)
 
@@ -312,7 +315,7 @@ func TestInterceptor_ExecuteTrigger_ShouldNotContinue(t *testing.T) {
 func TestInterceptor_ExecuteTrigger_with_invalid_content_type(t *testing.T) {
 	ctx, _ := rtesting.SetupFakeContext(t)
 	logger := zaptest.NewLogger(t)
-	kubeClient := fakekubeclient.Get(ctx)
+	secretInformer := fakeSecretInformer.Get(ctx)
 	req := &triggersv1.InterceptorRequest{
 		Body: `{}`,
 		Header: http.Header{
@@ -327,8 +330,8 @@ func TestInterceptor_ExecuteTrigger_with_invalid_content_type(t *testing.T) {
 		},
 	}
 	w := &Interceptor{
-		KubeClientSet: kubeClient,
-		Logger:        logger.Sugar(),
+		SecretLister: secretInformer.Lister(),
+		Logger:       logger.Sugar(),
 	}
 	res := w.Process(ctx, req)
 	if res.Continue {
@@ -342,11 +345,11 @@ func TestInterceptor_ExecuteTrigger_with_invalid_content_type(t *testing.T) {
 func TestInterceptor_Process_InvalidParams(t *testing.T) {
 	ctx, _ := rtesting.SetupFakeContext(t)
 	logger := zaptest.NewLogger(t)
-	kubeClient := fakekubeclient.Get(ctx)
+	secretInformer := fakeSecretInformer.Get(ctx)
 
 	w := &Interceptor{
-		KubeClientSet: kubeClient,
-		Logger:        logger.Sugar(),
+		SecretLister: secretInformer.Lister(),
+		Logger:       logger.Sugar(),
 	}
 
 	req := &triggersv1.InterceptorRequest{
